@@ -683,7 +683,7 @@ class TerminalWindow(ScrollText):
                  self.showmessage(line)
 
     def addTab(self,caption:str,text:str,tabtype:int):
-        t=CodeText(self.pages,tabtype,background="black",foreground="white",font=("Courier",12,"bold"),insertbackground="white")
+        t=CodeText(self.pages,tabtype,background="black",foreground="white",font=("Courier",self.fontsize,"bold"),insertbackground="white")
         self.pages.add(t,text=caption)
         t.tw=self
         t.setText(text)
@@ -769,7 +769,9 @@ class TerminalWindow(ScrollText):
     def openEdit(self,name:str, upload:str, text:str):
         """Find and open a tab for a local edit"""
         re=self.findLocalEdit(name)
-        if not re:
+        if re:
+            re.setText(text)
+        else:
             re=self.addTab(name,text,CodeText.MODE_EDIT)
         re.upload=upload
         re.syntax=(upload.find("@program")>=0)
